#
# spec file for package python-vdirsyncer
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-vdirsyncer
Version:        0.16.7
Release:        bp154.2.21
Summary:        CalDAV and CardDAV synchronization module
License:        BSD-3-Clause
Group:          Productivity/Networking/News/Utilities
URL:            https://github.com/pimutils/vdirsyncer
Source0:        https://files.pythonhosted.org/packages/source/v/vdirsyncer/vdirsyncer-%{version}.tar.gz
Source1:        vdirsyncer.service
Source2:        vdirsyncer.timer
# https://github.com/pimutils/vdirsyncer/pull/779
# https://github.com/pimutils/vdirsyncer/issues/793
Patch0:         python-vdirsyncer-fix-tests.patch
# default deadline (200ms) is too short for obs
Patch1:         python-vdirsyncer-shift-deadline.patch
BuildRequires:  %{python_module atomicwrites}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(systemd)
Requires:       python-atomicwrites >= 0.1.7
Requires:       python-click >= 5.0
Requires:       python-click-log >= 0.3
Requires:       python-click-threading >= 0.2
Requires:       python-icalendar >= 3.6
Requires:       python-lxml
Requires:       python-python-dateutil
Requires:       python-pytz
Requires:       python-requests >= 2.4.1
Requires:       python-requests-toolbelt >= 0.4.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-requests-oauthlib
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module click-log >= 0.3}
BuildRequires:  %{python_module click-threading >= 0.2}
BuildRequires:  %{python_module hypothesis >= 3.1}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest-subtesthack}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.4.1}
BuildRequires:  %{python_module requests-toolbelt >= 0.4.40}
BuildRequires:  %{python_module urllib3}
# /SECTION
%ifpython3
Provides:       vdirsyncer = %{version}
Obsoletes:      vdirsyncer < %{version}
%endif
%python_subpackages

%description
Vdirsyncer synchronizes calendars and addressbooks between two
storages. The supported storages are CalDAV, CardDAV, arbitrary HTTP
resources, vdir and some more. It aims to be for CalDAV and CardDAV
what OfflineIMAP is for IMAP.

%prep
%setup -q -n vdirsyncer-%{version}
%patch0 -p1
%patch1 -p1
rm -rf vdirsyncer.egg-info

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/vdirsyncer
%python_expand %fdupes %{buildroot}/%{$python_sitelib}

mkdir -p %{buildroot}%{_userunitdir}
install -Dpm 0644 %{SOURCE0} %{buildroot}%{_userunitdir}/vdirsyncer.service
install -Dpm 0644 %{SOURCE1} %{buildroot}%{_userunitdir}/vdirsyncer.timer

%check
export DETERMINISTIC_TESTS=true
# test_verbosity - click changed syntax and returns different quotes
%pytest -k 'not test_legacy_status and not test_open_graphical_browser and not test_verbosity'

%post
%python_install_alternative vdirsyncer

%postun
%python_uninstall_alternative vdirsyncer

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/vdirsyncer
%{python_sitelib}/*
%{_userunitdir}/vdirsyncer.service
%{_userunitdir}/vdirsyncer.timer

%changelog
* Sun Jun  7 2020 Matej Cepl <mcepl@suse.com>
- Add missing BR python-atomicwrites
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 29 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip failing test due to changed quoting in click:
  * test_verbosity
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Wed Jun  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Make the deadline for tests even larger, on slow obs bots
  it takes 1300:
  * python-vdirsyncer-shift-deadline.patch
* Thu May 16 2019 ranand@suse.com
- Skip flaky test test_legacy_status
* Tue May  7 2019 pgajdos@suse.com
- added patches
  default deadline (200ms) is too short for obs
  + python-vdirsyncer-shift-deadline.patch
* Mon May  6 2019 pgajdos@suse.com
- fix tests again https://github.com/pimutils/vdirsyncer/issues/793
- modified patches
  %% python-vdirsyncer-fix-tests.patch (extended)
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Wrap description.
* Fri Mar 29 2019 pgajdos@suse.com
- version update to 0.16.7
  Fixes for Python 3.7
- added patches
  https://github.com/pimutils/vdirsyncer/pull/779
  + python-vdirsyncer-fix-tests.patch
* Wed Jul 18 2018 mimi.vx@gmail.com
- fix vdirsyncer.timer service
* Wed Jul  4 2018 dmacvicar@suse.de
- Add systemd unit and timer from upstream git
- Make package python3 only
- Update to version 0.16.6
  * Documentation building no longer needs a working installation
    of vdirsyncer.
- Changes from version 0.16.5
  * click-log 0.3 is required.
  * All output will now happen on stderr (because of the upgrade of ``click-log``).
- Changes from version 0.16.4
  * Fix tests for new Hypothesis version. (Literally no other change included)
- Changes from version 0.16.3
  * First version with custom Debian and Ubuntu packages. See :gh:`663`.
  * Remove invalid ASCII control characters from server responses. See :gh:`626`.
  * Python 3.3 is no longer supported. See :ghpr:`674`.
- Changes from version 0.16.2
  * Fix crash when using daterange or item_type filters in
    :storage:`google_calendar`, see :gh:`657`.
  * Fixes for new version ``0.2.0`` of ``click-log``. The version
    requirements for the dependency ``click-log`` changed.
- Changes from version 0.16.1
  * Removed remoteStorage support, see :gh:`647`.
  * Fixed test failures caused by latest requests version, see :gh:`660`.
* Tue Jul  4 2017 aloisio@gmx.com
- Update to version 0.16.0
  * Strip METHOD:PUBLISH added by some calendar providers, see
    :gh:`502`.
  * Fix crash of Google storages when saving token file.
  * Make DAV discovery more RFC-conformant, see :ghpr:`585`.
  * Vdirsyncer is now tested against Xandikos, see :ghpr:`601`.
  * Subfolders with a leading dot are now ignored during
    discover for filesystem storage. This makes it easier to combine
    it with version control.
  * Statuses are now stored in a sqlite database. Old data is
    automatically migrated. Users with really large datasets should
    encounter performance improvements. This means that sqlite3 is
    now a dependency of vdirsyncer.
  * Vdirsyncer is now licensed under the 3-clause BSD license,
    see :gh:`610`.
  * Vdirsyncer now includes experimental support for EteSync,
    see :ghpr:`614`.
  * Vdirsyncer now uses more filesystem metadata for determining
    whether an item changed. You will notice a possibly heavy CPU/IO
    spike on the first sync after upgrading.
  * Packagers: Reference systemd.service and systemd.timer unit
    files are provided. It is recommended to install these as
    documentation if your distribution is systemd-based.
- Provides vdirsyncer only for python3.
* Fri Jun 30 2017 aloisio@gmx.com
- Update to 0.15.0 (see changelog.rst)
- Renamed to python-vdirsyncer
- Converted to single-spec
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Wed Nov  5 2014 seiler@b1-systems.de
- added needed python-requests-toolbelt dependency
* Tue Nov  4 2014 seiler@b1-systems.de
- initial commit
